/****************************************************************************
  FILE: wv.h, TomaszMajor-31Jul96, tmvr-v3.04b-21Mar97
  PURPOSE: wavelet elevation and texture compression for vrml viewer
  OBJECTS: ewv_t - elevation compression
           twv_t - texture compression
****************************************************************************/


#ifndef _WVVR_H
# define _WVVR_H
#ifdef __cplusplus
extern "C" {
#endif /*__cplusplus*/



/****************************************************************************
  FUNCTIONS:
    enc_ewv() - encode elevation;
    dec_ewv() - decode elevation;
    enc_twv() - encode texture;
    dec_twv() - decode texture;
  ARGUMENTS:
    int ysiz,xsiz - vertical and horizontal size of elev or texr [32,2048];
    float min,max - the span of elevations [-30000,30000];
    int num - number of elevation levels to be distinguishable;
    float *elev - elevation data [min,max] as line-by-line scan,
                  elev[ysiz*xsiz];
    unsigned char *texr - texture data [0,256) in headerless ppm format,
                          texr[3*ysiz*xsiz];
    unsigned char *stream - buffer for compressed data,
                            stream[*stream_len];
    long *stream_len - length of stream
                       input:[256,INT_MAX], output:[0,{input *stream_len}];
    int qlty - quality of picture [1,12);
    int scale - {1,2,4,8,16} stands for the linear scale 1:1, 1:2, 1:4 etc.;
  RETURN: int - quality [1,qlty] or a number<0 if not ok (check *stream_len);
****************************************************************************/
#define ewv_t void

extern ewv_t *new_ewv(int ysiz,int xsiz,float min,float max,int num);

extern void delete_ewv(ewv_t **ewv);

extern int enc_ewv(ewv_t *ewv,
		   float *elev,
		   unsigned char *stream,int *stream_len,
		   int qlty);
        	   
extern int dec_ewv(ewv_t *ewv,
		   unsigned char *stream,int *stream_len,
		   float *elev,
		   int qlty,int scale); 


#define twv_t void

extern twv_t *new_twv(int ysiz,int xsiz);

extern void delete_twv(twv_t **twv);

extern int enc_twv(twv_t *twv,
		   unsigned char *texr,
		   unsigned char *stream,int *stream_len,
		   int qlty); 
        	   
extern int dec_twv(twv_t *twv,
		   unsigned char *stream,int *stream_len,
		   unsigned char *texr,
		   int qlty,int scale); 



#ifdef __cplusplus
}
#endif /*__cplusplus*/
#endif /*!_WVVR_H*/


